@@ -1,5 +1,7 @@
 from ..utils.filesystem_utils import get_file_contents
 from ..utils.configuration import Configuration
+import asset
+from logging import getLogger
 
 class Report:
     class Status:
@@ -10,16 +12,18 @@ class Report:
     TEMPLATE_LOCATION = Configuration.get_configuration()[Configuration.Key.REPORT_TEMPLATE_LOCATION]
 
     @staticmethod
-    def __get_report_template():
-        return get_file_contents(Report.TEMPLATE_LOCATION)
+    def __get_report_template() -> str:
+        return asset.load(Report.TEMPLATE_LOCATION).read().decode('utf-8')
 
     @staticmethod
     def __save_report(report, path):
-        with open(path, 'w+') as f:
+        getLogger(__name__).info(f"Saving report: '{report}'")
+        with open(path, 'w') as f:
             f.write(report)
 
     @staticmethod
     def write_report(status: Status):
+        logger = getLogger(__name__)
         template = Report.__get_report_template()
         report = template.format(status=status)
         Report.__save_report(report, Report.REPORT_LOCATION)
